#!/usr/bin/python

import datetime
from lpscripts import LaunchpadAPIScript


class LicenseNotice(LaunchpadAPIScript):
    WHITEBOARD_MESSAGE = """\
%(owner_display_name)s (%(owner_name)s) notified by email of licensing problems on %(today)s. --%(me)s"""

    SUBJECT = "Licensing for your project in Launchpad (%(project_name)s)"

    MSG_TEMPLATE = u"""\
Hello %(owner_name)s,

You registered the project '%(project_name)s' in Launchpad. I Have disabled
the project.

The project's license appears to discriminate against how the project's
work is used or who can use it. Launchpad does not consider such licenses
to be free, the license is seen as proprietary. This is the same
criteria that that the Open Source Initiative and the Free Software
Foundation use when determining if a license is open and free.

Launchpad is a collaboration site that is free to use for projects
with an approved open source license.  When you registered your
project the list of licenses presented are the ones we automatically
recognize.

Other licenses must follow the guidelines we list on the following
page in order to be approved:
https://help.launchpad.net/Legal/ProjectLicensing

Further information is on our FAQ "Can closed-source or proprietary
projects use Launchpad?" which can be found at:
https://answers.launchpad.net/launchpad/+faq/208

Proprietary projects can use Launchpad by purchasing a commercial-use
subscription which costs US$250/year/project.  Please follow the
instructions presented on your project overview page to purchase a
subscription voucher.  Feel free to contact me if you have any
questions.

Thanks,

%(me)s
Canonical, Ltd.
"""
    USAGE="""\
%prog [options] [projects]

'projects' is a list of project names or URLs to projects in
Launchpad.  These projects will be notified of our licensing
policies.
"""

    def process_project(self, proj):
        """See `LaunchpadAPIScript`."""
        licenses = proj.licenses

        if proj.owner.name == self.REGISTRY_TEAM:
            print "Project owner is the registry team, skipping."
            return

        if proj.active:
            owner = proj.owner
            if owner.is_team:
                owner = owner.team_owner
            proj.project_reviewed = True
            proj.license_approved = False
            proj.active = False
            proj.lp_save()
            self.send_email(proj, owner)
            self.update_whiteboard(proj, owner)
        else:
            print "is already disabled, skipping."


if __name__ == "__main__":

    script = LicenseNotice()
    script.run()
