#!/usr/bin/python

from lpscripts import LaunchpadAPIScript


class LicenseNotice(LaunchpadAPIScript):
    RTM_SUBJECT = "Review project %(project_name)s"

    RTM_MESSAGE="""
Licensing email sent %(now)s for project %(project_name)s.
Please ensure the licensing is now correct.
"""

    WHITEBOARD_MESSAGE = """\
%(owner_display_name)s (%(owner_name)s) notified by email of licensing problems on %(today)s. --%(me)s"""

    SUBJECT = "Licensing for your project in Launchpad (%(project_name)s)"

    MSG_TEMPLATE = u"""\
Hello %(owner_name)s,

You recently updated '%(project_name)' in Launchpad with a license
of 'Other/Open Source'.

The license information you provided has some conflicts with Launchpad's
policy for free hosting of open source projects. So long as Launchpad is
not used to host or distribute non-free applications, your project
qualifies for free hosting. The code that was recently upload is fine.
Your project is approved, but take care not to include the proprietary
apps in any branches or to include them in an archive.

Launchpad is a collaboration site that is free to use for projects
with an approved open source license.  When you registered your
project the list of licenses presented are the ones we automatically
recognize.

Other licenses must follow the guidelines we list on the following
page in order to be approved:
https://help.launchpad.net/Legal/ProjectLicensing

Further information is on our FAQ "Can closed-source or proprietary
projects use Launchpad?" which can be found at:
https://answers.launchpad.net/launchpad/+faq/208

If your project's licensing does not meet the guidelines we will
consider it "Proprietary" and mark it as such in Launchpad.

Proprietary projects can use Launchpad by purchasing a commercial-use
subscription which costs US$250/year/project.  Please follow the
instructions presented on your project overview page to purchase a
subscription voucher.  Feel free to contact me if you have any
questions.

If the license for your project needs to be corrected you can do so by
following the 'Change Details' link on your project's overview page.

Thanks,

%(me)s
Canonical, Ltd.
"""
    USAGE="""\
%prog [options] [projects]

'projects' is a list of project names or URLs to projects in
Launchpad.  These projects will be notified of our licensing
policies.
"""


    def addParserOptions(self):
        """Add additional parse options."""
        super(LicenseNotice, self).addParserOptions()

        self.parser.add_option(
            '--due',
            type='string', default='1 week',
            dest='due',
            help="""\
Length of time before the item is to be reviewed, in RTM notation.
e.g '1 week' or '2 days'.  Default is 1 week.""")

        self.parser.add_option(
            '--tags',
            type='string', default='+license_review',
            dest='rtm_tags',
            help="""\
RTM tags to use.  Default is +license_review.""")

        self.parser.add_option(
            '--list',
            type='string', default='Licensing',
            dest='rtm_list',
            help="""\
RTM list to use.  Default is Licensing.""")

        # Override the default.
        self.parser.add_option(
            '--rtm',
            type='string', default=self.RTM_ADDRESS,
            dest='rtm_address',
            help="""\
Provide your RememberTheMilk.com address for emailing tasks.  It can be found under
the 'Settings->Info' tab in RTM.  The default is to use the Launchpad group account.""")

    def process_project(self, proj):
        """See `LaunchpadScript`."""
        licenses = proj.licenses

        if len(licenses) == 0:
            print "%s no license specified." % proj.name
            return
        elif not ('Other/Open Source' in licenses or
                'Other/Proprietary' in licenses):
            print "%s does not have licensing issues." % proj.name
            return

        if proj.owner.name == self.REGISTRY_TEAM:
            print "Project owner is the registry team, skipping."
            return

        if proj.active:
            owner = proj.owner
            if owner.is_team:
                owner = owner.team_owner
            proj.project_reviewed = True
            proj.lp_save()
            self.send_email(proj, owner)
            self.update_whiteboard(proj, owner)
        else:
            print "is already disabled, skipping."


if __name__ == "__main__":

    script = LicenseNotice()
    script.run()
